// java wrapper for vtkChart object
//

package vtk;
import vtk.*;

public class vtkChart extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean Paint_2(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_2(id0); }

  private native long AddPlot_3(int id0);
  public vtkPlot AddPlot(int id0) {
    long temp = AddPlot_3(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int AddPlot_4(vtkPlot id0);
  public int AddPlot(vtkPlot id0)
    { return AddPlot_4(id0); }

  private native boolean RemovePlot_5(int id0);
  public boolean RemovePlot(int id0)
    { return RemovePlot_5(id0); }

  private native boolean RemovePlotInstance_6(vtkPlot id0);
  public boolean RemovePlotInstance(vtkPlot id0)
    { return RemovePlotInstance_6(id0); }

  private native void ClearPlots_7();
  public void ClearPlots()
    { ClearPlots_7(); }

  private native long GetPlot_8(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_8(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPlots_9();
  public int GetNumberOfPlots()
    { return GetNumberOfPlots_9(); }

  private native long GetAxis_10(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_10(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAxis_11(int id0,vtkAxis id1);
  public void SetAxis(int id0,vtkAxis id1)
    { SetAxis_11(id0,id1); }

  private native int GetNumberOfAxes_12();
  public int GetNumberOfAxes()
    { return GetNumberOfAxes_12(); }

  private native void RecalculateBounds_13();
  public void RecalculateBounds()
    { RecalculateBounds_13(); }

  private native void SetSelectionMethod_14(int id0);
  public void SetSelectionMethod(int id0)
    { SetSelectionMethod_14(id0); }

  private native int GetSelectionMethod_15();
  public int GetSelectionMethod()
    { return GetSelectionMethod_15(); }

  private native void SetAnnotationLink_16(vtkAnnotationLink id0);
  public void SetAnnotationLink(vtkAnnotationLink id0)
    { SetAnnotationLink_16(id0); }

  private native long GetAnnotationLink_17();
  public vtkAnnotationLink GetAnnotationLink() {
    long temp = GetAnnotationLink_17();

    if (temp == 0) return null;
    return (vtkAnnotationLink)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGeometry_18(int id0,int id1);
  public void SetGeometry(int id0,int id1)
    { SetGeometry_18(id0,id1); }

  private native void SetGeometry_19(int id0[]);
  public void SetGeometry(int id0[])
    { SetGeometry_19(id0); }

  private native int[]  GetGeometry_20();
  public int[]  GetGeometry()
    { return GetGeometry_20(); }

  private native void SetPoint1_21(int id0,int id1);
  public void SetPoint1(int id0,int id1)
    { SetPoint1_21(id0,id1); }

  private native void SetPoint1_22(int id0[]);
  public void SetPoint1(int id0[])
    { SetPoint1_22(id0); }

  private native int[]  GetPoint1_23();
  public int[]  GetPoint1()
    { return GetPoint1_23(); }

  private native void SetPoint2_24(int id0,int id1);
  public void SetPoint2(int id0,int id1)
    { SetPoint2_24(id0,id1); }

  private native void SetPoint2_25(int id0[]);
  public void SetPoint2(int id0[])
    { SetPoint2_25(id0); }

  private native int[]  GetPoint2_26();
  public int[]  GetPoint2()
    { return GetPoint2_26(); }

  private native void SetShowLegend_27(boolean id0);
  public void SetShowLegend(boolean id0)
    { SetShowLegend_27(id0); }

  private native boolean GetShowLegend_28();
  public boolean GetShowLegend()
    { return GetShowLegend_28(); }

  private native long GetLegend_29();
  public vtkChartLegend GetLegend() {
    long temp = GetLegend_29();

    if (temp == 0) return null;
    return (vtkChartLegend)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTitle_30(String id0);
  public void SetTitle(String id0)
    { SetTitle_30(id0); }

  private native String GetTitle_31();
  public String GetTitle()
    { return GetTitle_31(); }

  private native long GetTitleProperties_32();
  public vtkTextProperty GetTitleProperties() {
    long temp = GetTitleProperties_32();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBottomBorder_33(int id0);
  public void SetBottomBorder(int id0)
    { SetBottomBorder_33(id0); }

  private native void SetTopBorder_34(int id0);
  public void SetTopBorder(int id0)
    { SetTopBorder_34(id0); }

  private native void SetLeftBorder_35(int id0);
  public void SetLeftBorder(int id0)
    { SetLeftBorder_35(id0); }

  private native void SetRightBorder_36(int id0);
  public void SetRightBorder(int id0)
    { SetRightBorder_36(id0); }

  private native void SetBorders_37(int id0,int id1,int id2,int id3);
  public void SetBorders(int id0,int id1,int id2,int id3)
    { SetBorders_37(id0,id1,id2,id3); }

  private native void SetLayoutStrategy_38(int id0);
  public void SetLayoutStrategy(int id0)
    { SetLayoutStrategy_38(id0); }

  private native int GetLayoutStrategy_39();
  public int GetLayoutStrategy()
    { return GetLayoutStrategy_39(); }

  private native void SetAutoSize_40(boolean id0);
  public void SetAutoSize(boolean id0)
    { SetAutoSize_40(id0); }

  private native boolean GetAutoSize_41();
  public boolean GetAutoSize()
    { return GetAutoSize_41(); }

  private native void SetRenderEmpty_42(boolean id0);
  public void SetRenderEmpty(boolean id0)
    { SetRenderEmpty_42(id0); }

  private native boolean GetRenderEmpty_43();
  public boolean GetRenderEmpty()
    { return GetRenderEmpty_43(); }

  private native void SetActionToButton_44(int id0,int id1);
  public void SetActionToButton(int id0,int id1)
    { SetActionToButton_44(id0,id1); }

  private native int GetActionToButton_45(int id0);
  public int GetActionToButton(int id0)
    { return GetActionToButton_45(id0); }

  private native void SetClickActionToButton_46(int id0,int id1);
  public void SetClickActionToButton(int id0,int id1)
    { SetClickActionToButton_46(id0,id1); }

  private native int GetClickActionToButton_47(int id0);
  public int GetClickActionToButton(int id0)
    { return GetClickActionToButton_47(id0); }

  private native void SetBackgroundBrush_48(vtkBrush id0);
  public void SetBackgroundBrush(vtkBrush id0)
    { SetBackgroundBrush_48(id0); }

  private native long GetBackgroundBrush_49();
  public vtkBrush GetBackgroundBrush() {
    long temp = GetBackgroundBrush_49();

    if (temp == 0) return null;
    return (vtkBrush)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionMode_50(int id0);
  public void SetSelectionMode(int id0)
    { SetSelectionMode_50(id0); }

  private native int GetSelectionMode_51();
  public int GetSelectionMode()
    { return GetSelectionMode_51(); }

  public vtkChart() { super(); }

  public vtkChart(long id) { super(id); }

}
